.. raw:: rst
   :file: badges.rst

.. _unittests-label: Test

.. raw:: rst
   :file: long_description.rst

.. raw:: rst

   Build status: |build-status|
   
   Read the documentation: |docs|
   
..

.. raw:: rst
   :file: install.rst

.. include:: changelog.rst

